@@ -800,6 +800,10 @@ def checkBox(widget, master, value, label, box=None,
     cbox.toggled[bool].connect(cbox.makeConsistent)
     cbox.makeConsistent(value)
     miscellanea(cbox, b, widget, **misc)
+
+    # QTBUG-2699
+    cbox.setAttribute(Qt.WA_LayoutUsesWidgetRect)
+
     return cbox
 
 
@@ -999,6 +1003,10 @@ def button(widget, master, label, callback=None, width=None, height=None,
         button.clicked.connect(callback)
 
     miscellanea(button, None, widget, **misc)
+
+    # QTBUG-2699
+    button.setAttribute(Qt.WA_LayoutUsesWidgetRect)
+
     return button
 
 
@@ -1404,8 +1412,7 @@ def valueSlider(widget, master, value, box=None, label=None,
 def comboBox(widget, master, value, box=None, label=None, labelWidth=None,
              orientation=Qt.Vertical, items=(), callback=None,
              sendSelectedValue=None, emptyString=None, editable=False,
-             contentsLength=None, maximumContentsLength=25, searchable=False,
-             *, model=None, **misc):
+             contentsLength=None, searchable=False, *, model=None, **misc):
     """
     Construct a combo box.
 
@@ -1448,17 +1455,10 @@ def comboBox(widget, master, value, box=None, label=None, labelWidth=None,
             combo.setSizeAdjustPolicy(
                 QComboBox.AdjustToMinimumContentsLengthWithIcon)
             combo.setMinimumContentsLength(contentsLength)
-    :param int maximumContentsLength: deprecated 4.5.0
     :param searchable: decides whether combo box has search-filter option
     :type searchable: bool
     :rtype: QComboBox
     """
-    if maximumContentsLength != 25:
-        warnings.warn(
-            f"'maximumContentsLength' is deprecated and has no effect. It "
-            "will be removed in orange-widget-base 4.6",
-            FutureWarning
-        )
     widget_label = None
     if box or label:
         hb = widgetBox(widget, box, orientation, addToLayout=False)
@@ -1490,6 +1490,7 @@ def comboBox(widget, master, value, box=None, label=None, labelWidth=None,
             combo.addItem(str(item))
 
     if value:
+        combo.setObjectName(value)
         cindex = getdeepattr(master, value)
         if model is not None:
             combo.setModel(model)
@@ -1523,6 +1524,10 @@ def comboBox(widget, master, value, box=None, label=None, labelWidth=None,
         log.warning("comboBox no longer accepts argument 'valueType'")
     miscellanea(combo, hb, widget, **misc)
     combo.emptyString = emptyString
+
+    # QTBUG-2699
+    combo.setAttribute(Qt.WA_LayoutUsesWidgetRect)
+
     return combo
 
 
@@ -1898,8 +1903,12 @@ class CallFrontComboBox(ControlledCallFront):
             try:
                 index = items.index(value or self.emptyString)
             except ValueError:
-                log.warning("Unable to set '{}' to '{}'; valid values are '{}'".
-                            format(self.control, value, ", ".join(items)))
+                if items:
+                    msg = f"Combo '{combo.objectName()}' has no item '{value}'; " \
+                          f"current items are {', '.join(map(repr, items))}."
+                else:
+                    msg = f"combo '{combo.objectName()}' is empty."
+                warnings.warn(msg, stacklevel=5)
             else:
                 self.control.setCurrentIndex(index)
 
@@ -1907,8 +1916,13 @@ class CallFrontComboBox(ControlledCallFront):
             if value < combo.count():
                 combo.setCurrentIndex(value)
             else:
-                log.warning("Unable to set '{}' to {}; largest index is {}".
-                            format(combo, value, combo.count() - 1))
+                if combo.count():
+                    msg = f"index {value} is out of range " \
+                          f"for combo box '{combo.objectName()}' " \
+                          f"with {combo.count()} item(s)."
+                else:
+                    msg = f"combo box '{combo.objectName()}' is empty."
+                warnings.warn(msg, stacklevel=5)
 
         combo = self.control
         if isinstance(value, int):
