@@ -1,4 +1,5 @@
-from collections import defaultdict, Sequence
+from collections import defaultdict
+from typing import Sequence
 from math import isnan, isinf
 from numbers import Number, Integral
 
@@ -255,7 +256,9 @@ class PyTableModel(AbstractSortTableModel):
         self._editable = editable
         self._table = None
         self._roleData = None
-        self.wrap(sequence or [])
+        if sequence is None:
+            sequence = []
+        self.wrap(sequence)
 
     def rowCount(self, parent=QModelIndex()):
         return 0 if parent.isValid() else len(self)
@@ -619,8 +622,11 @@ class PyListModel(QAbstractListModel):
 
     def extend(self, iterable):
         list_ = list(iterable)
+        count = len(list_)
+        if count == 0:
+            return
         self.beginInsertRows(QModelIndex(),
-                             len(self), len(self) + len(list_) - 1)
+                             len(self), len(self) + count - 1)
         self._list.extend(list_)
         self._other_data.extend([_store() for _ in list_])
         self.endInsertRows()
@@ -680,6 +686,8 @@ class PyListModel(QAbstractListModel):
     def __delitem__(self, s):
         if isinstance(s, slice):
             start, stop, _ = _as_contiguous_range(s, len(self))
+            if not len(self) or start == stop:
+                return
             self.beginRemoveRows(QModelIndex(), start, stop - 1)
         else:
             s = operator.index(s)
@@ -696,6 +704,8 @@ class PyListModel(QAbstractListModel):
 
             if not isinstance(value, list):
                 value = list(value)
+            if len(value) == 0:
+                return
             separators = [start + i for i, v in enumerate(value) if v is self.Separator]
             self.beginInsertRows(QModelIndex(), start, start + len(value) - 1)
             self._list[start:start] = value
